<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:java="http://xml.apache.org/xslt/java"
	xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
	xmlns:gslib="http://www.greenstone.org/skinning"
	extension-element-prefixes="java util"
	exclude-result-prefixes="java util">

	<xsl:variable name="groupPath"><xsl:value-of select="/page/pageRequest/paramList/param[@name='group']/@value"/></xsl:variable>
	
	<!-- use the 'main' layout -->
	<!--<xsl:include href="layouts/main.xsl"/>-->

	<!-- set page title -->
	<xsl:template name="pageTitle"><xsl:choose><xsl:when test="$groupPath != ''"><gslib:groupName path="{$groupPath}"/></xsl:when><xsl:otherwise><gslib:siteName/></xsl:otherwise></xsl:choose></xsl:template>

	<!-- set page breadcrumbs -->
	<xsl:template name="breadcrumbs">
		<xsl:if test="$groupPath != ''">
			<gslib:siteLink/>
			<xsl:for-each select="/page/pageResponse/pathList/group">
				<xsl:sort data-type="number" select="@position"/>
				<gslib:rightArrow/>
				<xsl:if test="position() != last()">
				  <!-- don't want the current group in the breadcrumbs -->
				  <a>
				    <xsl:attribute name="href"><gslib:groupHref path="{@path}"/></xsl:attribute>				
				    <xsl:attribute name="title"><gslib:groupName path="{@path}"/></xsl:attribute>
				    <gslib:groupName path="{@path}"/>
				  </a>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
	
	<!-- the page content -->
	<xsl:template match="/page/pageResponse">
	  <div class="main-wrap">
	    <div id="wsite-content" class="wsite-elements wsite-not-footer">
	      <div class="wsite-section-wrap">
		<div class="wsite-section wsite-body-section wsite-background-14"  >
		  <div class="wsite-section-content">
		    <div class="container">
		      <div class="wsite-section-elements">
			<xsl:if test="groupList/group">
			  <div class="paragraph" style="text-align:center;">
<div class="paragraph" style="text-align:center;">Our purpose is <strong style="color:rgb(63, 63, 63)"><em>&#x201C;Kia rangatira ai ngā uri o te Whakatōhea&#x201D; &#150; &#x201C;To lift our nation, and to grow and invest in the well-being of our people&#x201D;.</em></strong><br /><span style="color:rgb(63, 63, 63)">The Whakatōhea Māori Trust Board</span> exists to improve the lives of its people <br />through the six <em><strong>&#x201C;50-year Strategic Goals&#x201D;</strong></em>. These are defined as the following <strong>Six Pou:</strong> <br /></div>
			  </div>
			</xsl:if>
			<!-- NO LONGER A PROBLEM AS THE DL SITE IS NOW EMBEDDED IN AN IFRAME
			     AND SO DOES NOT PROVIDE THE FOOTER OF THE whakatohea.co.nz SITE.
			     Forced to add nbsp (which in XSL is &#160;) in div.wsite-spacer
			     because otherwise text overflows from the main page into footer 
			     caused by html rendering of div.wsite-spacer's subsequent sibling
			     divs as *children* of div.wsite-spacer instead.
			     Beware that XSL errors ensue if &nbsp; is used as it's not a defined
			     entity in XSL, only in HTML. Must use &#160; for nbsp in XSL, see
			     https://stackoverflow.com/questions/1461649/how-to-insert-nbsp-in-xslt
			-->
			<!--
			<div class="wsite-spacer" style="height:50px;">
			  &#160; &#160; &#160;
			</div>-->
			<div><div class="wsite-multicol"><div class="wsite-multicol-table-wrap" style="margin:0 -15px;">
			  <table class="wsite-multicol-table">
			    <tbody class="wsite-multicol-tbody">
			      <tr class="wsite-multicol-tr">
				<!-- <xsl:call-template name="collectionAndGroupLinks"/> -->

				<!-- output the groups, the following outputs them column wise -->
				<xsl:apply-templates select="groupList/group" mode="displayGroupInfo" />
				<!-- then output the collectionList in a final column -->
				<xsl:apply-templates select="collectionList/collection" mode="displayCollInfo" />
			      </tr>
			      
			    </tbody>
			  </table>
			</div></div></div>
		      </div>
		    </div>
		  </div>
		  
		</div>
	      </div>
	      
	    </div>
	  </div><!-- end class main-wrap-->
	</xsl:template>

	<xsl:template name="additionalHeaderContent">
		<script type="text/javascript" src="interfaces/{$interface_name}/scripts/jquery.easing.1.3.js"><xsl:text> </xsl:text></script>
		<script type="text/javascript" src="interfaces/{$interface_name}/scripts/jquery.timers.1.2.js"><xsl:text> </xsl:text></script>
		<script type="text/javascript" src="interfaces/{$interface_name}/scripts/jquery.galleryview.2.1.1.min.js"><xsl:text> </xsl:text></script>
		<script type="text/javascript" src="interfaces/{$interface_name}/scripts/jquery.galleryview.setup.js"><xsl:text> </xsl:text></script>
	</xsl:template>
	
	<xsl:template name="collectionsList">
	  	<!-- for every collection in the library -->
		<xsl:for-each select="./collectionList/collection">		
			<xsl:call-template name="collDescription"/>				
		</xsl:for-each>
	</xsl:template>
	
	<!--
	    Template has match and name attributes allowing this to be called with both
	    apply-templates and call-template.
	    https://stackoverflow.com/questions/6478163/can-an-xslt-template-carry-both-name-and-match-attributes
	-->
	<xsl:template match="collection" name="collDescription" mode="displayColl">
	  <xsl:variable name="collectionFolder" select="@name"/>
	  <xsl:variable name="collectionName" select="displayItemList/displayItem[@name='name']"/>
	  <xsl:variable name="aboutImage" select="displayItemList/displayItem[@name='icon']"/>
	  <xsl:variable name="homeImage" select="displayItemList/displayItem[@name='smallicon']"/>
	  <xsl:variable name="collDesc" select="displayItemList/displayItem[@name='description']"/>
	  <xsl:variable name="numDocs" select="metadataList/metadata[@name='numDocs']"/>
	  <!-- creates a header that links to the collection's about page -->
	  
	  <!-- if there is an About page image for the collection, this is displayed -->
	  <xsl:if test="$homeImage">
	    <div><div class="wsite-image wsite-image-border-thin " style="padding-top:10px;padding-bottom:10px;margin-left:0;margin-right:0;text-align:center">
	      <img src="sites/{$site_name}/collect/{$collectionFolder}/images/{$homeImage}" alt="{$collectionName}" title="{$collectionName}" style="max-width:100%" />
	    </div></div>
	    <div style="display:block;font-size:90%"></div>
	  </xsl:if>

	  <!-- don't centre collection description (div class=paragraph)
	       with style="text-align:center;
	       since the collection description may be HTML in its own right -->
	  <div class="paragraph">
	    <a href="{$library_name}/collection/{$collectionFolder}/page/about" title="{$collectionName}" alt="{$collectionName}"><xsl:value-of select="$collectionName"/></a>
	    <br />
	    <xsl:choose>
	      <!-- has a description - display it -->
	      <xsl:when test="$collDesc">
		
		<!--<xsl:value-of select="$collDesc" disable-output-escaping="yes"/>--><xsl:apply-templates select="displayItemList/displayItem[@name='description']"/>
	      </xsl:when>
	      <!-- no description - a generic sentence -->
	      <xsl:otherwise>
		<p class="justify">Welcome to the <xsl:value-of select="$collectionName"/> collection. This collection contains <xsl:value-of select="$numDocs"/> documents.</p>
	      </xsl:otherwise>
	    </xsl:choose>
	  </div>
	</xsl:template>
	
	<xsl:template name="collectionAndGroupLinks">
	  <xsl:for-each select="collectionList/collection|groupList/group">
            <xsl:sort data-type="number" select="@position"/>
	    <td class="wsite-multicol-col" style="width:33.333333333333%; padding:0 15px;">
	      <xsl:if test="name() = 'collection'">
		<xsl:call-template name="collDescription"/>
	      </xsl:if>
	      <xsl:if test="name() = 'group'">	      
		<xsl:call-template name="customGroupDescription"/>
	      </xsl:if>
	    </td>
          </xsl:for-each>
	</xsl:template>
	
	<!-- https://stackoverflow.com/questions/93511/counter-inside-xslfor-each-loop
	will not work, since we have an if-statement inside the for loop to filter for groups.
	Instead, counting only the groups using Borodin's solution (still xslt 1.0) from
	https://stackoverflow.com/questions/16504727/increment-counter-in-xslt-1-0 works.

	While that gives us a proper counter not dependent on position(), it doesn't solve
	that we need to open a tag (td) on odd count and close it on even.
	For that, the solution is at:
	https://stackoverflow.com/questions/17992481/xsl-wrap-every-2-items-in-the-for-each-with-a-div

	General: https://stackoverflow.com/questions/4478045/what-are-the-differences-between-call-template-and-apply-templates-in-xsl
	-->
	<xsl:template match="group" mode="displayGroupInfo">
	  <xsl:variable name="counter"><xsl:value-of select="1+count(preceding-sibling::group)])"/></xsl:variable>
	  <xsl:if test="($counter mod 2) = 1">
	    <td class="wsite-multicol-col" style="width:33.333333333333%; padding:0 15px;">
	      <xsl:apply-templates select=". |  following-sibling::group[1]" />
	      <!-- calls the template match="group" without mode this time -->
	    </td>
	  </xsl:if>
	</xsl:template>

	<!-- We want collections to appear in a separate and single column.
	     So we don't do even odd columns here. -->
	<xsl:template match="collection" mode="displayCollInfo">
	  <!--<xsl:variable name="counter"><xsl:value-of select="1+count(preceding-sibling::collection)])"/></xsl:variable>
	  <xsl:if test="($counter mod 2) = 1">-->
	    <td class="wsite-multicol-col" style="width:33.333333333333%; padding:0 15px;">
	      <!--<xsl:apply-templates select=". |  following-sibling::collection[1]" />-->
	      <xsl:apply-templates select="." mode="displayColl"/>
		      <!-- why does calling the template match="collection" without some mode
			   attr this time NOT work? -->
	    </td>
	  <!--</xsl:if>-->
	</xsl:template>	

	<xsl:template match="/page/xsltparams">
	  <!-- suppress xsltparam block in page -->
	</xsl:template>

	<!-- Modified version of <gslib:groupLinkWithImage/>-->
	<!-- 
	     Template has match and name attributes allowing this to be called with both
	     apply-templates and call-template.
	     https://stackoverflow.com/questions/6478163/can-an-xslt-template-carry-both-name-and-match-attributes
	-->
	<xsl:template match="group" name="customGroupDescription">

	  <xsl:variable name="short"><xsl:value-of select="shortDescription"/></xsl:variable>
	  <xsl:variable name="desc"><xsl:value-of select="description"/></xsl:variable>
	  <xsl:variable name="group_href"><xsl:value-of select="$library_name"/>/group/<xsl:if test="/page/pageRequest/paramList/param[@name='group']"><xsl:value-of select="/page/pageRequest/paramList/param[@name='group']/@value"/>/</xsl:if><xsl:value-of select="@name"/></xsl:variable>
	  
	  <div class="img-and-desc">
	  <!-- if there is an image for this group, this is displayed -->	  
	  <xsl:if test="util:checkFileExistence($site_name, backgroundImage)">
	    <div class="wsite-image wsite-image-border-thin " style="padding-top:10px;padding-bottom:10px;margin-left:0;margin-right:0;text-align:center">
	      <!-- the group (pou) image links to the collection's about page -->
	      <a href="{$group_href}" title="{$short}" alt="{$short}">
		<div style="background-color:#404040;margin-left:11px; margin-right: 11px;">
		  <img class="groupLinkImage">
		    <xsl:attribute name="alt"><xsl:value-of select="@name"/></xsl:attribute>
		    <xsl:attribute name="title"><xsl:value-of select="@name"/></xsl:attribute>
		    <xsl:attribute name="style"><xsl:text>max-width:100%;opacity:0.4;padding: 0 !important;</xsl:text></xsl:attribute>
		    <xsl:attribute name="src">sites/<xsl:value-of select="$site_name"/>/<xsl:value-of select="backgroundImage"/></xsl:attribute>
		  </img>
		</div>
	      </a>
	    </div>

	  </xsl:if>

	  <!-- group description also links to the collection's about page
	       since it is overlaid on the image with absolute positioning
	       and therefore obscures the image link
	  -->
	  <!-- some text for the group -->
	  <a href="{$group_href}" title="{$short}" alt="{$short}">
	  <div class="paragraph">
	    <span class="pou-group-title">
	      <xsl:choose>
		<xsl:when test="boolean(title)">
		  <xsl:value-of select="title"/>
		</xsl:when>
		<xsl:otherwise>
		  <xsl:value-of select="@name"/>
		</xsl:otherwise>
	      </xsl:choose>
	    </span>
	    <br />	    
	    <xsl:choose>
	      <!-- If the group has a description - display it -->
	      <xsl:when test="$desc">
		<xsl:value-of select="$desc" disable-output-escaping="yes"/>
	      </xsl:when>
	      <!-- If no group description - repeat group name -->
	      <xsl:otherwise>
		Collection group: <xsl:value-of select="@name" disable-output-escaping="yes"/>
	      </xsl:otherwise>
	    </xsl:choose>
	  </div><!--end div.paragraph-->
	  </a>
	</div><!-- end div.img-and-desc-->
	   <!-- <div style="display:block;font-size:90%"></div>	  -->
	</xsl:template>

</xsl:stylesheet>


